Uploader Python Module
=============================================

.. automodule:: pacifica.policy.uploader
   :members:
   :private-members:
   :special-members:
.. automodule:: pacifica.policy.uploader.rest
   :members:
   :private-members:
   :special-members:
